// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef MAILIMPORTER_VERSION_H
#define MAILIMPORTER_VERSION_H

#define MAILIMPORTER_VERSION_STRING "6.7.3"
#define MAILIMPORTER_VERSION_MAJOR 6
#define MAILIMPORTER_VERSION_MINOR 7
#define MAILIMPORTER_VERSION_PATCH 3
#define MAILIMPORTER_VERSION ((6<<16)|(7<<8)|(3))

#endif
